@@ -153,6 +153,7 @@ gboolean                nautilus_file_is_executable                     (Nautilu
 gboolean                nautilus_file_is_directory                      (NautilusFile                   *file);
 gboolean                nautilus_file_is_in_trash                       (NautilusFile                   *file);
 gboolean                nautilus_file_is_in_desktop                     (NautilusFile                   *file);
+gboolean		nautilus_file_is_home				(NautilusFile                   *file);
 GnomeVFSResult          nautilus_file_get_file_info_result              (NautilusFile                   *file);
 gboolean                nautilus_file_get_directory_item_count          (NautilusFile                   *file,
 									 guint                          *count,
@@ -185,7 +186,7 @@ gboolean                nautilus_file_can_set_group                     (Nautilu
 char *                  nautilus_file_get_owner_name                    (NautilusFile                   *file);
 char *                  nautilus_file_get_group_name                    (NautilusFile                   *file);
 GList *                 nautilus_get_user_names                         (void);
-GList *                 nautilus_get_group_names                        (void);
+GList *                 nautilus_get_all_group_names                    (void);
 GList *                 nautilus_file_get_settable_group_names          (NautilusFile                   *file);
 
 /* "Capabilities". */
