@@ -58,7 +58,8 @@ static LinkStyle
 get_link_style_for_mime_type (const char *mime_type)
 {
 	if (mime_type != NULL) {
-		if (g_ascii_strcasecmp (mime_type, "application/x-gnome-app-info") == 0) {
+		if (g_ascii_strcasecmp (mime_type, "application/x-gnome-app-info") == 0 ||
+		    g_ascii_strcasecmp (mime_type, "application/x-desktop") == 0) {
 			return desktop;
 		}
 		if (g_ascii_strcasecmp (mime_type, "application/x-nautilus-link") == 0) {
@@ -108,7 +109,8 @@ get_link_style_for_data (const char *file_contents, int file_size)
 
 gboolean
 nautilus_link_local_create (const char *directory_uri,
-			    const char *name,
+			    const char        *file_name,
+			    const char        *display_name,
 			    const char *image,
 			    const char *target_uri,
 			    const GdkPoint *point,
@@ -116,7 +118,8 @@ nautilus_link_local_create (const char *directory_uri,
 			    NautilusLinkType type)
 {
 	return nautilus_link_desktop_file_local_create (directory_uri,
-							name, image,
+							file_name,
+							display_name, image,
 							target_uri, 
 							point, screen,
 							type);
