@@ -39,20 +39,6 @@ typedef void (*NautilusApplicationChoiceCallback) (GnomeVFSMimeApplication	 *app
 typedef void (*NautilusComponentChoiceCallback)   (NautilusViewIdentifier 	 *identifier,
 						   gpointer		 	  callback_data);
 
-void nautilus_choose_application_for_file        (NautilusFile                      *file,
-						  GtkWindow                         *parent_window,
-						  NautilusApplicationChoiceCallback  callback,
-						  gpointer                           callback_data);
-void nautilus_cancel_choose_application_for_file (NautilusFile                      *file,
-						  NautilusComponentChoiceCallback    callback,
-						  gpointer                           callback_data);
-void nautilus_choose_component_for_file          (NautilusFile                      *file,
-						  GtkWindow                         *parent_window,
-						  NautilusComponentChoiceCallback    callback,
-						  gpointer                           callback_data);
-void nautilus_cancel_choose_component_for_file   (NautilusFile                      *file,
-						  NautilusComponentChoiceCallback    callback,
-						  gpointer                           callback_data);
 void nautilus_launch_application                 (GnomeVFSMimeApplication           *application,
 						  NautilusFile                      *file,
 						  GtkWindow                         *parent_window);
@@ -65,5 +51,7 @@ void nautilus_launch_desktop_file		 (GdkScreen                         *screen,
 						  const char                        *desktop_file_uri,
 						  const GList                       *parameter_uris,
 						  GtkWindow                         *parent_window);
-
+void nautilus_launch_show_file                   (NautilusFile                      *file,
+                                                  GtkWindow                         *parent_window);
+						  
 #endif /* NAUTILUS_PROGRAM_CHOOSING_H */
