@@ -64,6 +64,7 @@
 #include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-tree-view-drag-dest.h>
 #include <libnautilus/nautilus-scroll-positionable.h>
+#include <libnautilus/nautilus-clipboard.h>
 #include <libnautilus-private/nautilus-cell-renderer-pixbuf-emblem.h>
 
 /* Included for the typeselect flush delay */
@@ -1415,6 +1416,8 @@ fm_list_view_set_selection (FMDirectoryView *view, GList *selection)
 	list_view = FM_LIST_VIEW (view);
 	tree_selection = gtk_tree_view_get_selection (list_view->details->tree_view);
 
+	g_signal_handlers_block_by_func (tree_selection, list_selection_changed_callback, view);
+
 	gtk_tree_selection_unselect_all (tree_selection);
 	for (node = selection; node != NULL; node = node->next) {
 		file = node->data;
@@ -1422,6 +1425,9 @@ fm_list_view_set_selection (FMDirectoryView *view, GList *selection)
 			gtk_tree_selection_select_iter (tree_selection, &iter);
 		}
 	}
+
+	g_signal_handlers_unblock_by_func (tree_selection, list_selection_changed_callback, view);
+	fm_directory_view_notify_selection_changed (view);
 }
 
 static void
@@ -1847,6 +1853,11 @@ fm_list_view_start_renaming_file (FMDirectoryView *view, NautilusFile *file)
 	gtk_editable_select_region (GTK_EDITABLE (entry), start_offset, end_offset);
 	
 	gtk_tree_path_free (path);
+
+	nautilus_clipboard_set_up_editable_in_control
+		(GTK_EDITABLE (entry),
+		 fm_directory_view_get_bonobo_control (view),
+		 FALSE);
 }
 
 static void
@@ -1934,6 +1945,16 @@ fm_list_view_sort_directories_first_changed (FMDirectoryView *view)
 							 fm_directory_view_should_sort_directories_first (view));
 }
 
+static void
+fm_list_view_sort_files (FMDirectoryView *view, GList **files)
+{
+	FMListView *list_view;
+
+	list_view = FM_LIST_VIEW (view);
+
+	fm_list_model_sort_files (list_view->details->model, files);
+}
+
 static void
 fm_list_view_dispose (GObject *object)
 {
@@ -2096,6 +2117,7 @@ fm_list_view_class_init (FMListViewClass *class)
 	fm_directory_view_class->reveal_selection = fm_list_view_reveal_selection;
 	fm_directory_view_class->select_all = fm_list_view_select_all;
 	fm_directory_view_class->set_selection = fm_list_view_set_selection;
+	fm_directory_view_class->sort_files = fm_list_view_sort_files;
 	fm_directory_view_class->sort_directories_first_changed = fm_list_view_sort_directories_first_changed;
 	fm_directory_view_class->start_renaming_file = fm_list_view_start_renaming_file;
 	fm_directory_view_class->zoom_to_level = fm_list_view_zoom_to_level;
