@@ -964,6 +964,20 @@ nautilus_application_present_spatial_window (NautilusApplication *application,
 					     NautilusWindow      *requesting_window,
 					     const char          *location,
 					     GdkScreen           *screen)
+{
+	return nautilus_application_present_spatial_window_with_selection (application,
+									   requesting_window,
+									   location,
+									   NULL,
+									   screen);
+}
+
+NautilusWindow *
+nautilus_application_present_spatial_window_with_selection (NautilusApplication *application,
+					     NautilusWindow      *requesting_window,
+					     const char          *location,
+					     GList		 *new_selection,
+					     GdkScreen           *screen)
 {
 	NautilusWindow *window;
 	GList *l;
@@ -984,6 +998,9 @@ nautilus_application_present_spatial_window (NautilusApplication *application,
 
 		if (eel_uris_match (existing_location, location)) {
 			gtk_window_present (GTK_WINDOW (existing_window));
+			if (new_selection) {
+				nautilus_view_frame_selection_changed (existing_window->content_view, new_selection);
+			}
 			return existing_window;
 		}
 	}
@@ -1016,7 +1033,7 @@ nautilus_application_present_spatial_window (NautilusApplication *application,
 	g_object_weak_ref (G_OBJECT (window), 
 			   spatial_window_destroyed_callback, NULL);
 	
-	nautilus_window_go_to (window, location);
+	nautilus_window_go_to_with_selection (window, location, new_selection);
 	
 	return window;
 }
@@ -1143,7 +1160,11 @@ volume_unmounted_callback (GnomeVFSVolumeMonitor *monitor,
 	/* Handle the windows in the close list. */
 	for (node = close_list; node != NULL; node = node->next) {
 		window = NAUTILUS_WINDOW (node->data);
-		nautilus_window_close (window);
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			nautilus_window_close (window);
+		} else {
+			nautilus_window_go_home (window);
+		}
 	}
 		
 	g_list_free (close_list);
@@ -1211,12 +1232,11 @@ static void
 update_session (gpointer callback_data)
 {
 	set_session_restart (callback_data,
-			     eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ADD_TO_SESSION)
 			     /* Only ever add ourselves to the session
 			      * if we have a desktop window. Prevents the
 			      * session thrashing that's seen otherwise
 			      */
-			     && nautilus_application_desktop_windows != NULL);
+			     nautilus_application_desktop_windows != NULL);
 }
 
 static void
@@ -1232,10 +1252,6 @@ init_session (void)
 	g_signal_connect (client, "die",
 			  G_CALLBACK (removed_from_session), NULL);
 	
-	eel_preferences_add_callback
-		(NAUTILUS_PREFERENCES_ADD_TO_SESSION,
-		 update_session, client);
-
 	update_session (client);
 }
 
