@@ -138,6 +138,21 @@ nautilus_navigation_window_instance_init (NautilusNavigationWindow *window)
 	bonobo_window_set_contents (BONOBO_WINDOW (window), window->details->content_paned);
 }
 
+static void
+file_menu_new_window_callback (BonoboUIComponent *component,
+			       gpointer user_data,
+			       const char *verb)
+{
+	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
+
+	const gchar    *uri = nautilus_window_get_location (window);
+
+	window = nautilus_application_create_navigation_window (window->application,
+						gtk_window_get_screen (GTK_WINDOW (window)));
+
+	nautilus_window_open_location (window, uri, FALSE);
+}
+
 static void
 go_to_callback (GtkWidget *widget,
 		const char *uri,
@@ -703,6 +718,10 @@ real_merge_menus (NautilusWindow *nautilus_window)
 	GtkWidget *location_bar_box;
 	GtkWidget *view_as_menu_vbox;
 	BonoboControl *location_bar_wrapper;
+	BonoboUIVerb verbs [] = {
+		BONOBO_UI_VERB ("New Window", file_menu_new_window_callback),
+		BONOBO_UI_VERB_END
+	};
 
 	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS, 
 			 merge_menus, (nautilus_window));
@@ -717,6 +736,9 @@ real_merge_menus (NautilusWindow *nautilus_window)
 	bonobo_ui_component_freeze 
 		(NAUTILUS_WINDOW (window)->details->shell_ui, NULL);
 
+	bonobo_ui_component_add_verb_list_with_data (nautilus_window->details->shell_ui,
+						     verbs, window);
+
 	nautilus_navigation_window_initialize_menus_part_1 (window);
 	nautilus_navigation_window_initialize_toolbars (window);
 
@@ -1429,6 +1451,34 @@ nautilus_navigation_window_show (GtkWidget *widget)
 	GTK_WIDGET_CLASS (parent_class)->show (widget);
 }
 
+static void
+nautilus_navigation_window_save_geometry (NautilusNavigationWindow *window)
+{
+	char *geometry_string;
+
+	g_assert (NAUTILUS_IS_WINDOW (window));
+
+	if (GTK_WIDGET(window)->window &&
+	    !(gdk_window_get_state (GTK_WIDGET(window)->window) & GDK_WINDOW_STATE_MAXIMIZED)) {
+		geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
+		
+		if (eel_preferences_key_is_writable (NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY)) {
+			eel_preferences_set
+				(NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY, 
+				 geometry_string);
+		}
+		g_free (geometry_string);
+	}
+}
+
+
+
+static void
+real_window_close (NautilusWindow *window)
+{
+	nautilus_navigation_window_save_geometry (NAUTILUS_NAVIGATION_WINDOW (window));
+}
+
 static void 
 real_get_default_size(NautilusWindow *window, guint *default_width, guint *default_height)
 {
@@ -1459,4 +1509,5 @@ nautilus_navigation_window_class_init (NautilusNavigationWindowClass *class)
 	NAUTILUS_WINDOW_CLASS (class)->prompt_for_location = real_prompt_for_location;
 	NAUTILUS_WINDOW_CLASS (class)->set_title = real_set_title;
 	NAUTILUS_WINDOW_CLASS(class)->get_default_size = real_get_default_size;
+	NAUTILUS_WINDOW_CLASS (class)->close = real_window_close;
 }
