@@ -680,10 +680,11 @@ open_location (NautilusWindow *window,
 			}
 		} else if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
                         if (!NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change) {
-                                target_window = nautilus_application_present_spatial_window (
+                                target_window = nautilus_application_present_spatial_window_with_selection (
                                         window->application,
 					window,
                                         location,
+					new_selection,
                                         gtk_window_get_screen (GTK_WINDOW (window)));
                                 do_load_location = FALSE;
                         } else {
@@ -1152,7 +1153,6 @@ cancel_location_change (NautilusWindow *window)
         end_location_change (window);
 }
 
-
 static gboolean
 pending_location_already_showing (NautilusWindow *window)
 {
@@ -1179,6 +1179,23 @@ pending_location_already_showing (NautilusWindow *window)
 	return FALSE;
 }
 
+static gboolean
+another_navigation_window_already_showing (NautilusWindow *the_window)
+{
+	GList *list, *item;
+	
+	list = nautilus_application_get_window_list ();
+	for (item = list; item != NULL; item = item->next) {
+		if (item->data != the_window &&
+		    NAUTILUS_IS_NAVIGATION_WINDOW (item->data)) {
+			return TRUE;
+		}
+	}
+	
+	return FALSE;
+}
+
+
 static void
 load_directory_metadata_callback (NautilusFile *file,
 				  gpointer callback_data)
@@ -1230,15 +1247,41 @@ load_directory_metadata_callback (NautilusFile *file,
                 }
                 g_free (geometry_string);
 
-		/* load the saved scroll position */
-		scroll_string = nautilus_file_get_metadata 
-			(file, NAUTILUS_METADATA_KEY_WINDOW_SCROLL_POSITION,
-			 NULL);
+		if (window->details->pending_selection == NULL) {
+			/* If there is no pending selection, then load the saved scroll position. */
+			scroll_string = nautilus_file_get_metadata 
+				(file, NAUTILUS_METADATA_KEY_WINDOW_SCROLL_POSITION,
+				 NULL);
+		} else {
+			/* If there is a pending selection, we want to scroll to an item in
+			 * the pending selection list. */
+			scroll_string = g_strdup (window->details->pending_selection->data);
+		}
+
+		/* scroll_string might be NULL if there was no saved scroll position. */
 		if (scroll_string != NULL) {
 			window->details->pending_scroll_to = scroll_string;
 		}
         }
 #endif
+        if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
+		geometry_string = eel_preferences_get
+				(NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY);
+                if (geometry_string != NULL &&
+		    geometry_string[0] != 0) {
+			/* Ignore saved window position if a window with the same
+			 * location is already showing. That way the two windows
+			 * wont appear at the exact same location on the screen.
+			 */
+                        eel_gtk_window_set_initial_geometry_from_string 
+                                (GTK_WINDOW (window), 
+                                 geometry_string,
+                                 NAUTILUS_WINDOW_MIN_WIDTH, 
+                                 NAUTILUS_WINDOW_MIN_HEIGHT,
+				 another_navigation_window_already_showing (window));
+                }
+                g_free (geometry_string);
+	}
 
 	
 	/* finish loading the view */
